/*******************************************************************************
* ers.h			definitions to be used in conjunction with the
*				eurogam register server c library
*/
#ifndef INCersh
#define INCersh

#include <rpc/rpc.h> /* for definition of CLIENT */

#define ERS_VERS 0

#ifndef OK /* define possible function returns */

#define OK 0
#define ERROR (-1)

#endif  /* OK */

#ifndef TRUE

#define FALSE 0
#define TRUE 1 

#endif  /* TRUE */

#define ERS_RPC_ERROR (-1)	/* errno value : may decide on something else */

typedef struct capabilityBuffer /* buffer big enough to hold a capability */
{
	char theContentsOfThisBufferShouldNotBeReferenced [8];
} CAP;

typedef struct registerList /* linked list of register names */
{
	char *reg;
	int cookie;
	struct registerList *next;
} REG_LIST;

typedef struct registerValueList /* linked list of register values */
{
	char *reg;
	u_int length;
	char *value;
	int cookie;
	struct registerValueList *next;
} VAL_LIST;

extern int errno;

#ifdef	__STDC__

extern void		ersFreeMemory ();
extern CLIENT *	ersInitialise (char *host);
extern CLIENT * ersOpenClient (char *host, int port);
extern void		ersCloseClient (CLIENT *client);
extern char *	ersErrMsg (int num);
extern char *	ersPerror (char *string);
extern char *	ersVersion ();

extern int		ersNullProc (CLIENT *client);
extern int		ersClaimResource (CLIENT *client, char *resource, CAP *capability);
extern int		ersFreeResource	(CLIENT *client, CAP *capability, char *resource);
extern int		ersDefineRegister (CLIENT *client, CAP *capability,char *resource, char *reg, char *prototype);
extern int		ersUndefineRegister (CLIENT *client,CAP *capability, char *resource, char *reg);
extern int		ersReadRegister (CLIENT *client, CAP *capability, char *resource, char *reg, char *value);
extern int		ersWriteRegister (CLIENT *client, CAP *capability, char *resource, char *reg, int length, char *value);
extern int		ersInitialiseRegister (CLIENT *client, CAP *capability, char *resource, char *reg);
extern int		ersInquireRegisters (CLIENT *client, CAP *capability, char *resource, char *pattern, int cookie, int count, REG_LIST **list);
extern int		ersReadRegisters (CLIENT *client, CAP *capability, char *resource, char *pattern, int cookie, int count, VAL_LIST **list);
extern int		ersWriteRegisters (CLIENT *client, CAP *capability, char *resource, char *pattern, int length, char *value);
extern int		ersInitialiseRegisters (CLIENT *client, CAP *capability, char *resource, char *pattern);
extern int		ersReadAttribute (CLIENT *client, CAP *capability, char *resource, char *reg, char *value);
extern int		ersWriteAttribute (CLIENT *client, CAP *capability, char *resource, char *reg, int length, char *value);
extern int		ersUndefineRegisters (CLIENT *client,CAP *capability, char *resource, char *pattern);
extern int		ersReadAttributes (CLIENT *client, CAP *capability, char *resource, char *pattern, int cookie, int count, VAL_LIST **list);
extern int		ersWriteAttributes (CLIENT *client, CAP *capability, char *resource, char *pattern, int length, char *value);
extern int		ersConfigureResource (CLIENT *client, CAP *capability, char *resource, char *file);

#else

extern void		ersFreeMemory ();
extern CLIENT *	ersInitialise ();
extern CLIENT * ersOpenClient ();
extern void		ersCloseClient ();
extern char *	ersErrMsg ();
extern char *	ersPerror ();
extern char *	ersVersion ();

extern int		ersNullProc ();
extern int 		ersClaimResource ();
extern int		ersFreeResource ();
extern int		ersDefineRegister ();
extern int		ersUndefineRegister ();
extern int		ersReadRegister ();
extern int		ersWriteRegister ();
extern int		ersInitialiseRegister ();
extern int		ersReadRegisters ();
extern int		ersWriteRegisters ();
extern int		ersInitialiseRegisters ();
extern int		ersReadAttribute ();
extern int		ersWriteAttribute ();
extern int		ersUndefineRegisters ();
extern int		ersReadAttributes ();
extern int		ersWriteAttributes ();
extern int 		ersConfigureResource ();

#endif	/* __STDC__ */

#endif /* DEFersh */
